@@ -682,7 +682,7 @@ class HDF5Reader:
         self.f.close()
 
     # ----------------------------------------------------------------------
-    def get_epochs(self, tmax: int, tmin: Optional[int] = 0, markers: Union[None, List[str]] = None, preprocess=None, **kwargs) -> mne.EpochsArray:
+    def get_epochs(self, tmax: int, tmin: Optional[int] = 0, markers: Union[None, List[str]] = None, preprocess=None, eeg=None, **kwargs) -> mne.EpochsArray:
         """Create an `EpochsArray` object with the `MNE` library.
 
         This method auto crop the data in regard to markers also will drop
@@ -705,6 +705,8 @@ class HDF5Reader:
         epochs
             An MNE Epochs object.
         """
+        if eeg is None:
+            eeg = self.eeg
 
         if 'montage' in self.header:
             montage = self.header['montage']
@@ -753,8 +755,8 @@ class HDF5Reader:
                 i0 = int(start + (tmin * sampling_rate))
                 i1 = int(start + (tmax * sampling_rate))
 
-                if i1 < self.eeg.shape[1]:
-                    data.append(self.eeg[:, i0:i1])
+                if i1 < eeg.shape[1]:
+                    data.append(eeg[:, i0:i1])
                     classes.append(class_)
                 else:
                     no_fit += 1
@@ -770,11 +772,17 @@ class HDF5Reader:
         else:
             data = np.array(data)
 
+        # raw = mne.io.RawArray(data, info, first_samp=0,
+                              # copy='auto', verbose=None)
+        # return mne.Epochs(raw, events=events, tmin=tmin, event_id=event_id, **kwargs)
+
         return mne.EpochsArray(data, info, events=events, tmin=tmin, event_id=event_id, **kwargs)
 
     # ----------------------------------------------------------------------
-    def to_edf(self, filename: str) -> None:
+    def to_edf(self, filename: str, eeg=None) -> None:
         """Export to EDF file."""
+        if eeg is None:
+            eeg = self.eeg
 
         if 'sample_rate' in self.header:
             sampling_rate = self.header['sample_rate']
@@ -786,7 +794,7 @@ class HDF5Reader:
         edf_data_list = []
 
         for i, channel in enumerate(self.header['channels']):
-            data = self.eeg[i]
+            data = eeg[i]
             if data.max() == data.min():
                 max_, min_ = 1, -1
             else:
@@ -864,7 +872,7 @@ class HDF5Reader:
         f.close()
 
     # ----------------------------------------------------------------------
-    def get_data(self, tmax: int, tmin: Optional[int] = 0, markers: Union[None, List[str]] = None, **kwargs) -> Tuple[np.ndarray]:
+    def get_data(self, tmax: int, tmin: Optional[int] = 0, markers: Union[None, List[str]] = None, eeg=None, preprocess=None, **kwargs) -> Tuple[np.ndarray]:
         """Create an `EpochsArray` object with the `MNE` library.
 
         This method auto crop the data in regard to markers also will drop
@@ -890,7 +898,8 @@ class HDF5Reader:
             List of classes
         """
 
-        epochs = self.get_epochs(tmax, tmin, markers)
+        epochs = self.get_epochs(
+            eeg, tmax, tmin, markers, preprocess=preprocess)
         return epochs._data, epochs.events[:, 2]
 
     # # ----------------------------------------------------------------------
@@ -906,8 +915,11 @@ class HDF5Reader:
             # return 0
 
     # ----------------------------------------------------------------------
-    def to_npy(self, filename, tmin=None, tmax=None):
+    def to_npy(self, filename, eeg=None, tmin=None, tmax=None):
         """"""
+        if eeg is None:
+            eeg = self.eeg
+
         filename = os.path.abspath(filename)
         tmp_dir = os.path.join(os.path.dirname(filename), 'tmp_dir_npy')
         if os.path.exists(tmp_dir):
@@ -915,11 +927,11 @@ class HDF5Reader:
         os.mkdir(tmp_dir)
 
         if (tmin is None) and (tmax is None):
-            np.save(os.path.join(tmp_dir, 'eeg'), self.eeg)
+            np.save(os.path.join(tmp_dir, 'eeg'), eeg)
             np.save(os.path.join(tmp_dir, 'timestamp'), self.timestamp)
         else:
-            eeg, classes = self.get_data(tmin=tmin, tmax=tmax)
-            np.save(os.path.join(tmp_dir, 'eeg'), eeg)
+            eeg_, classes = self.get_data(eeg, tmin=tmin, tmax=tmax)
+            np.save(os.path.join(tmp_dir, 'eeg'), eeg_)
             np.save(os.path.join(tmp_dir, 'classes'), classes)
 
         np.save(os.path.join(tmp_dir, 'markers'), self.markers)
